#!/bin/bash -e
# RSAS INSTALL SCRIPT FOR LINUX 
# You must run this as root.
# This script is safe to run over an existing RSAS installation and will not overwrite your
# config file.

if (( $EUID != 0 )); then
    echo "Please run this install script as root."
    exit
fi

# Create rsas user and group
echo "Creating rsas user and group"
getent group rsas >/dev/null 2>&1 || \
    addgroup --system --quiet rsas
    id rsas >/dev/null 2>&1 || \
        adduser --system --quiet --disabled-password --disabled-login \
            --home /usr/share/rsas/webroot --no-create-home --ingroup rsas rsas

SYSTEMD=0
if [ -d "/usr/lib/systemd/system" ]; then
    SYSTEMD=1
fi

echo "Creating directories..."
mkdir -p /usr/share/rsas
mkdir -p /usr/share/rsas/webroot
mkdir -p /var/log/rsas

echo "Copying files..."
DPERM='-m 0664 -g rsas -o rsas'
install -d ${DPERM} /usr/share/rsas/templates
install -d ${DPERM} /usr/share/rsas/webroot/images
install -d ${DPERM} /usr/share/rsas/webroot/css
install -d ${DPERM} /etc/rsas

install -D ${DPERM} templates/* /usr/share/rsas/templates
install -D ${DPERM} images/* /usr/share/rsas/webroot/images
install -D ${DPERM} css/* /usr/share/rsas/webroot/css
install -D ${DPERM} etc/rsas/* /etc/rsas

if [ ${SYSTEMD} -eq 1 ]; then
   install -m 0664 systemd/rsas.service /usr/lib/systemd/system/
fi

echo "Tightening permissions..."
chown -R rsas: /usr/share/rsas /var/log/rsas /etc/rsas
# Make these folders group writable to help transition from Icecast to RSAS.
chmod -R u=rw,g=rw,o=r,ugo+X /usr/share/rsas /var/log/rsas
# Set configuration rw for user and group, and no read for others.
chmod -R u=rw,g=rw,o=,ugo+X /etc/rsas
# Tightened permissions for the example config file
chmod -R ug=rw,o=,ug+X /etc/rsas/rsas.xml.example_simple

echo '*** Installation Complete ***'
echo 'Next step: You must manually create your /etc/rsas/rsas.xml configuration file.'
echo 'You can copy and use /etc/rsas/rsas.xml.example-simple as a starting point.'
if [ ${SYSTEMD} -eq 1 ]; then
    echo 'Once you have a config, start RSAS with:'
    echo '    $ systemctl rsas start'
else
    echo 'systemd was not detected, so you will need to manually set up the RSAS service for your init system.'
fi
